import { Component } from "@angular/core";
import { AddEditMasterRoomComponent } from "./add-edit-master-room/add-edit-master-room.component";
import { TableApiService } from "src/app/_services/table-api.service";
import { NgbModal } from "@ng-bootstrap/ng-bootstrap";
import { Router } from "@angular/router";
import { BuildingService } from "../../service/monitoring-api.service";
import { LoginService } from "../../service/login.service";
import { ToastrService } from "ngx-toastr";

@Component({
  selector: "app-master-room",
  templateUrl: "./master-room.component.html",
  styleUrls: ["./master-room.component.css"],
})
export class MasterRoomComponent {
  data: any;
  filteredRows: any[];
  searchTerm: string = "";
  rows: any = [];
  public breadcrumb: any;

  constructor(
    private modalService: NgbModal,
    private monitoringApiService: BuildingService,
    private authService: LoginService,
    private toastr: ToastrService
  ) {}

  ngOnInit() {
    this.authService.startTokenCheck();
    this.authService.startTrackingActivity();
    this.breadcrumb = {
      mainlabel: "Master Room",
      links: [
        {
          name: "Home",
          isLink: false,
        },
        {
          name: "Master Room",
          isLink: false,
        },
      ],
    };
    this.fetchData();
  }

  fetchData() {
    this.monitoringApiService.getMasterRoomData().subscribe((res) => {
      this.data = res;
      this.filteredRows = this.data.results.data.sort((a, b) => b.id - a.id);
      // this.data.results.data.sort((a, b) => b.id - a.id);
      console.log(this.filteredRows);
    });
  }

  filterRows() {
    if (!this.searchTerm) {
      this.filteredRows = [...this.data.results.data];
    } else {
      const searchTermLC = this.searchTerm.toLowerCase();
      this.filteredRows = this.data.results.data.filter((row) =>
        this.rowContainsSearchTerm(row, searchTermLC)
      );
    }
  }

  rowContainsSearchTerm(row: any, searchTermLC: string): boolean {
    return (
      row.name.toLowerCase().includes(searchTermLC) ||
      row.description.toLowerCase().includes(searchTermLC) ||
      row.code.toLowerCase().includes(searchTermLC) 
    );
  }

  openAddMasterModal() {
    const modalRef = this.modalService.open(AddEditMasterRoomComponent, {
      size: "lg",
      backdrop: "static",
      keyboard: false,
    });

    modalRef.componentInstance.mode = "add";
    modalRef.result.then(
      (result) => {
        if (result) {
          const filteredData = {
            name: result.name,
            code: result.code.trim(),
            description: result.description,
          };
          this.monitoringApiService
            .postMasterRoomParam(filteredData)
            .subscribe((res) => {
              this.fetchData();
            }, (error) => {
              console.error(error);
              this.toastr.error("Error", error.error.message, {
                timeOut: 2000,
                closeButton: true,
              });
            });
        }
      },
      (reason) => {
        console.log(`Dismissed: ${reason}`);
      }
    );
  }

  editRow(row) {
    const modalRef = this.modalService.open(AddEditMasterRoomComponent, {
      size: "lg",
      backdrop: "static", // Add this line
      keyboard: false, // Add this line
    });

    modalRef.componentInstance.dataRow = row;
    modalRef.componentInstance.mode = "edit";
    modalRef.result.then(
      (result) => {
        if (result) {
          const filteredData = {
            id: result.roomId,
            name: result.name,
            code: result.code.trim(),
            description: result.description,
          };
          this.monitoringApiService
            .putMasterRoomParam(filteredData, row.id)
            .subscribe((res) => {
              this.fetchData();
            }, (error) => {
              console.error(error);
              this.toastr.error("Error", error.error.message, {
                timeOut: 2000,
                closeButton: true,
              });
            });
        }
      },
      (reason) => {
        console.log(`Dismissed: ${reason}`);
      }
    );
  }

  deleteRow(row) {
    const confirmDelete = confirm("Are you sure you want to delete this item?");
    if (confirmDelete) {
      this.monitoringApiService
        .deleteRoom(row.id)
        .subscribe(
          (res) => {
            this.fetchData();
          },
          (error) => {
            console.error(error);
            this.toastr.error("Error", "Data sedang digunakan!", {
              timeOut: 2000,
              closeButton: true,
            });
          }
        );
    }
  }
}
